translate.misc.ourdom.DOMImplementation

Package translate :: Package misc :: Module ourdom :: Class DOMImplementation |
[hide private]
[frames] | no frames]

# Class DOMImplementation

source code

Instance Methods | [hide private]
_create_document(self) | source code
Inherited from `xml.dom.minidom.DOMImplementation`: `createDocument`, `createDocumentType`, `getInterface`, `hasFeature` Inherited from `xml.dom.xmlbuilder.DOMImplementationLS`: `createDOMBuilder`, `createDOMInputSource`, `createDOMWriter`

Class Variables | [hide private]
Inherited from `xml.dom.minidom.DOMImplementation` (private): `_features` Inherited from `xml.dom.xmlbuilder.DOMImplementationLS`: `MODE_ASYNCHRONOUS`, `MODE_SYNCHRONOUS`

Method Details | [hide private]

### _create_document(self) | source code
Overrides: xml.dom.minidom.DOMImplementation._create_document